# Aim-TTi TGF4000 Arbitrary Wave Generator

## Reference Documents

- [Aim-TTi TGF4000 Series Instruction Manual, v3.0](https://resources.aimtti.com/manuals/TGF4000_Series_Instruction_Manual-Iss3.pdf)